<template>
    <div class="loan-interest">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-债权.png')" title="借款利息趋势" routerPath="/platLayout/BondAssets"/>
        <div class="bottom-chart">
            <div id="interest-chart"></div>
        </div>
    </div>
</template>

<script>
import * as echarts from 'echarts'
import utils from '@/utils.js'
import api from '@/api/homePage.js'
import PublicTitle from '@/components/PublicTitle/index'
export default {
    name: 'LoanInterest', // 借款利息趋势
    components: { PublicTitle },
    data() {
        return {
            echartsData: []
        }
    },
    created() {
        this.getLoanAssets()
    },
    mounted() {
    },
    methods: {
        getLoanAssets() {
            api.loanStatistics({}, res => {
                if (res.state) {
                    this.echartsData = res.value
                }
                this.initChat()

            })
        },
        initChat() {
            let monthData=[]
            let nums=[]
            this.echartsData.forEach(e=>{
                monthData.push(e.month+'月')
                nums.push(e.addUpMoney)
            })
            let chartDom = echarts.init(
                document.getElementById('interest-chart')
            )
            let option = {
                tooltip: {
                    trigger: 'axis', // 设置触发类型为坐标轴轴线触发
                },
                grid: {
                    top: '21%',
                    bottom: '15%',
                    left: '6%',
                    right: '5%',
                },
                xAxis: {
                    type: 'category',
                    data:monthData,
                    boundaryGap: false,
                    axisTick: {
                        show: false,
                    },
                    axisLine: {
                        show: true,
                        lineStyle: {
                            color: '#A1A9B2', // 浅灰色
                        },
                    },
                },
                yAxis: {
                    type: 'value',
                    name: '单位：万元',
                    min: 0,
                    axisLine: {
                        show: true,
                        lineStyle: {
                            color: '#A1A9B2', // 浅灰色
                        },
                    },
                    splitLine: {
                        show: false,
                    },
                },
                series: [
                    {
                        data: nums,
                        type: 'line',
                        smooth: true,
                        // symbol: 'none', // 取消小圆点的显示
                        showSymbol: false, // 取消小圆点的显示
                        lineStyle: {
                            color: '#00FFFF', // 设置线条的颜色为红色
                        },
                    },
                ],
            }
            chartDom.setOption(option)
            window.addEventListener('resize', () => {
                chartDom.resize()
            })
        },
    },
}
</script>

<style scoped lang="scss">
.loan-interest {
    width: 100%;
    height: 100%;
    padding: 16px;
    box-sizing: border-box;
    background: #ffffff;
    box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
    border-radius: 16px 16px 16px 16px;

    .bottom-chart {
        width: 100%;
        height: calc(100% - 14px);

        #interest-chart {
            width: 100%;
            height: 100%;
        }
    }
}
</style>
